==> ihaskell-0.10.3.0-37-x86_64.pkg.tar.zst: usr/share/haskell/register/ihaskell.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 ihaskell
version:              0.10.3.0
visibility:           public
id:                   ihaskell-0.10.3.0-HCQDlnDOSFWL0m6qfW2iGk
key:                  ihaskell-0.10.3.0-HCQDlnDOSFWL0m6qfW2iGk
license:              MIT
maintainer:           andrew.gibiansky@gmail.com
author:               Andrew Gibiansky
homepage:             http://github.com/gibiansky/IHaskell
synopsis:             A Haskell backend kernel for the Jupyter project.
description:
    IHaskell is a Haskell backend kernel for the Jupyter project. This allows using Haskell via
    a console or notebook interface. Additional packages may be installed to provide richer data visualizations.

category:             Development
abi:                  a892b9a0197d5228e63ad6c8acedecbe
exposed:              True
exposed-modules:
    IHaskell.BrokenPackages IHaskell.CSS IHaskell.Convert
    IHaskell.Convert.Args IHaskell.Convert.IpynbToLhs
    IHaskell.Convert.LhsToIpynb IHaskell.Display
    IHaskell.Eval.Completion IHaskell.Eval.Evaluate
    IHaskell.Eval.Hoogle IHaskell.Eval.Info IHaskell.Eval.Inspect
    IHaskell.Eval.Lint IHaskell.Eval.ParseShell IHaskell.Eval.Parser
    IHaskell.Eval.Util IHaskell.Eval.Widgets IHaskell.Flags
    IHaskell.IPython IHaskell.IPython.Stdin IHaskell.Publish
    IHaskell.Types IHaskellPrelude Paths_ihaskell

hidden-modules:       StringUtils
import-dirs:          /usr/lib/ghc-9.0.2/site-local/ihaskell-0.10.3.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/ihaskell-0.10.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/ihaskell
hs-libraries:         HSihaskell-0.10.3.0-HCQDlnDOSFWL0m6qfW2iGk
depends:
    aeson-2.1.1.0-G096tWOvHRbG9p2kqAnbSl base-4.15.1.0
    base64-bytestring-1.2.1.0-5NRFEQpM8EqIeHRiZnTVYU binary-0.8.8.0
    bytestring-0.10.12.1 cmdargs-0.10.21-5dEStss8OK87s5amCxsPTV
    containers-0.6.4.1 directory-1.3.6.2 exceptions-0.10.4
    filepath-1.4.2.1 ghc-9.0.2 ghc-boot-9.0.2
    ghc-parser-0.2.4.0-C2YlX47cRq9Dr0ozlbj1lo
    ghc-paths-0.1.0.12-7fRPaqGgnC488dNzs2elDi haskeline-0.8.2
    hlint-3.3.6-DahrJj4p6mtJKUMYRJ7geu
    http-client-0.7.13.1-HTHpZxvH558FqmT2LYOw6J
    http-client-tls-0.3.6.1-ENCzfvTg0MYB5B6WS8IfRW
    ipython-kernel-0.10.3.0-5boDTsxevYrB7DRsFZGWK9 parsec-3.1.14.0
    process-1.6.13.2 random-1.2.1.1-E3NvGRfFQucB43UZdHlMm6
    shelly-1.10.0-8aeyO5WwrAYL9znDXCDnoe
    split-0.2.3.5-4mMY6dVe8QRLZUpvtheArp stm-2.5.0.0
    strict-0.4.0.1-2NFhjht3KmPAhVGmFElDue text-1.2.5.0 time-1.9.3
    transformers-0.5.6.2 unix-2.7.2.2
    unordered-containers-0.2.19.1-5gVbJUjVHi23RWuJCnXA3W
    utf8-string-1.0.2-9eFA57BgKXNHtjvfuIOq9f
    vector-0.13.0.0-dBvEOJ9xPHLRlUgENbcJF

haddock-interfaces:   /usr/share/doc/ihaskell/html/ihaskell.haddock
haddock-html:         /usr/share/doc/ihaskell/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> ihaskell-0.10.3.0-42-x86_64.pkg.tar.zst: usr/share/haskell/register/ihaskell.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 ihaskell
version:              0.10.3.0
visibility:           public
id:                   ihaskell-0.10.3.0-AbOtEhitrwJ57UBO86org6
key:                  ihaskell-0.10.3.0-AbOtEhitrwJ57UBO86org6
license:              MIT
maintainer:           andrew.gibiansky@gmail.com
author:               Andrew Gibiansky
homepage:             http://github.com/gibiansky/IHaskell
synopsis:             A Haskell backend kernel for the Jupyter project.
description:
    IHaskell is a Haskell backend kernel for the Jupyter project. This allows using Haskell via
    a console or notebook interface. Additional packages may be installed to provide richer data visualizations.

category:             Development
abi:                  d733a50ee4d12e8e019464b2560d2739
exposed:              True
exposed-modules:
    IHaskell.BrokenPackages IHaskell.CSS IHaskell.Convert
    IHaskell.Convert.Args IHaskell.Convert.IpynbToLhs
    IHaskell.Convert.LhsToIpynb IHaskell.Display
    IHaskell.Eval.Completion IHaskell.Eval.Evaluate
    IHaskell.Eval.Hoogle IHaskell.Eval.Info IHaskell.Eval.Inspect
    IHaskell.Eval.Lint IHaskell.Eval.ParseShell IHaskell.Eval.Parser
    IHaskell.Eval.Util IHaskell.Eval.Widgets IHaskell.Flags
    IHaskell.IPython IHaskell.IPython.Stdin IHaskell.Publish
    IHaskell.Types IHaskellPrelude Paths_ihaskell

hidden-modules:       StringUtils
import-dirs:          /usr/lib/ghc-9.0.2/site-local/ihaskell-0.10.3.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/ihaskell-0.10.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/ihaskell
hs-libraries:         HSihaskell-0.10.3.0-AbOtEhitrwJ57UBO86org6
depends:
    aeson-2.1.1.0-KfG6oaum90dLA5eXp6YCDc base-4.15.1.0
    base64-bytestring-1.2.1.0-JqlrLIjAgPuHn9bzuMbsro binary-0.8.8.0
    bytestring-0.10.12.1 cmdargs-0.10.21-5dEStss8OK87s5amCxsPTV
    containers-0.6.4.1 directory-1.3.6.2 exceptions-0.10.4
    filepath-1.4.2.1 ghc-9.0.2 ghc-boot-9.0.2
    ghc-parser-0.2.4.0-C2YlX47cRq9Dr0ozlbj1lo
    ghc-paths-0.1.0.12-7fRPaqGgnC488dNzs2elDi haskeline-0.8.2
    hlint-3.3.6-99xt6WA52ieIevJrX32OeF
    http-client-0.7.13.1-DWx7YNSyjEJG27wu9ROlyl
    http-client-tls-0.3.6.1-EwLcxd0DLfsDHIkyXORH2s
    ipython-kernel-0.10.3.0-AXPMO5EfKBr76tkP6XR2TY parsec-3.1.14.0
    process-1.6.13.2 random-1.2.1.1-2OCZakkUdz4CgwOx57VCs0
    shelly-1.10.0-FIIIkgjmoQ92Y6pFZU6goa
    split-0.2.3.5-HIKMdTQlRh8L3ExAbNDwpu stm-2.5.0.0
    strict-0.4.0.1-Aoe6x0f3ggZ3KVpcw4DCkS text-1.2.5.0 time-1.9.3
    transformers-0.5.6.2 unix-2.7.2.2
    unordered-containers-0.2.19.1-DnnZsztXxSKIeB0HgJzbzw
    utf8-string-1.0.2-9eFA57BgKXNHtjvfuIOq9f
    vector-0.13.0.0-CBdHfq8cDb33l37FQ8xap7

haddock-interfaces:   /usr/share/doc/ihaskell/html/ihaskell.haddock
haddock-html:         /usr/share/doc/ihaskell/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
